# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.users_v1_api import UsersV1Api


class TestUsersV1Api(unittest.TestCase):
    """UsersV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = UsersV1Api()

    def tearDown(self) -> None:
        pass

    def test_accept_my_invites(self) -> None:
        """Test case for accept_my_invites

        Accept User Invitations
        """
        pass

    def test_delete_user(self) -> None:
        """Test case for delete_user

        Delete User
        """
        pass

    def test_get_organization_users(self) -> None:
        """Test case for get_organization_users

        Get Users In An Organization.
        """
        pass

    def test_get_users_me(self) -> None:
        """Test case for get_users_me

        Get User Metadata
        """
        pass

    def test_patch_service_account_user(self) -> None:
        """Test case for patch_service_account_user

        Patch Service Account User.
        """
        pass

    def test_patch_user(self) -> None:
        """Test case for patch_user

        Patch User.
        """
        pass

    def test_post_organization_service_account(self) -> None:
        """Test case for post_organization_service_account

        Create Service Account
        """
        pass

    def test_post_organization_user(self) -> None:
        """Test case for post_organization_user

        Create User
        """
        pass

    def test_post_organization_user_invite(self) -> None:
        """Test case for post_organization_user_invite

        Create User Via Email Invite
        """
        pass

    def test_post_user_creds(self) -> None:
        """Test case for post_user_creds

        Regenerate User Credentials.
        """
        pass


if __name__ == '__main__':
    unittest.main()
