# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.jobs_v1_api import JobsV1Api


class TestJobsV1Api(unittest.TestCase):
    """JobsV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = JobsV1Api()

    def tearDown(self) -> None:
        pass

    def test_get_job(self) -> None:
        """Test case for get_job

        Get Job By Id
        """
        pass

    def test_get_job_errors(self) -> None:
        """Test case for get_job_errors

        Get Job Errors
        """
        pass

    def test_get_job_logs(self) -> None:
        """Test case for get_job_logs

        Get Job Logs
        """
        pass

    def test_get_job_runs(self) -> None:
        """Test case for get_job_runs

        Get Job Runs
        """
        pass

    def test_get_jobs(self) -> None:
        """Test case for get_jobs

        List Jobs
        """
        pass

    def test_post_dequeue_job(self) -> None:
        """Test case for post_dequeue_job

        Dequeue Job
        """
        pass

    def test_post_job_errors(self) -> None:
        """Test case for post_job_errors

        Append To Job Errors
        """
        pass

    def test_post_job_logs(self) -> None:
        """Test case for post_job_logs

        Append To Job Logs
        """
        pass

    def test_post_submit_jobs_batch(self) -> None:
        """Test case for post_submit_jobs_batch

        Submit Jobs Batch
        """
        pass

    def test_put_job_state(self) -> None:
        """Test case for put_job_state

        Update Job State
        """
        pass

    def test_update_job(self) -> None:
        """Test case for update_job

        Update Job By Id
        """
        pass


if __name__ == '__main__':
    unittest.main()
